@@ -2,12 +2,12 @@ use strict;
 use warnings;
 
 package OD::Prometheus::Set;
-$OD::Prometheus::Set::VERSION = '0.004';
+$OD::Prometheus::Set::VERSION = '0.005';
 use v5.24;
 use Moose;
 use LWP::UserAgent;
 use Data::Printer;
-use Scalar::Util qw(looks_like_number);
+use Scalar::Util qw(looks_like_number reftype);
 use OD::Prometheus::Metric;
 
 =head1 NAME
@@ -16,7 +16,7 @@ OD::Prometheus::Set - A set of Prometheus metrics
 
 =head1 VERSION
 
-version 0.004
+version 0.005
 
 =cut
 
@@ -43,6 +43,14 @@ sub is_empty {
 	$_[0]->size == 0
 }
 
+sub pop {
+	pop $_[0]->metrics->@*
+}
+
+sub item {
+	$_[0]->metrics->[ $_[1] ]
+}
+
 sub find {
 	my $self	= shift // die 'incorrect call';
 	my $metric	= shift // die 'incorrect call';
@@ -74,5 +82,19 @@ sub find {
 	return $rs
 }
 
+sub each {
+	my $self	= shift // die 'incorrect call';
+	my $func	= shift // die 'incorrect call';
+	die '2nd argument must be a subroutine reference' unless reftype( $func ) eq 'CODE';
+	for ( $self->metrics->@* ) {
+		$func->()
+	}
+}	
+
+sub value {
+	die 'Please do not call value on a Set that does not have exactly 1 item' unless $_[0]->size == 1;
+	$_[0]->item(0)->value
+}
+
 
 1;
